@@ -34,7 +34,13 @@ from . import (
 from .__about__ import __version__
 from ._common import topological_dimension
 from ._exceptions import ReadError, WriteError
-from ._helpers import extension_to_filetype, read, write, write_points_cells
+from ._helpers import (
+    extension_to_filetype,
+    read,
+    register_format,
+    write,
+    write_points_cells,
+)
 from ._mesh import CellBlock, Mesh
 
 __all__ = [
@@ -71,6 +77,7 @@ __all__ = [
     "_cli",
     "read",
     "write",
+    "register_format",
     "write_points_cells",
     "extension_to_filetype",
     "Mesh",
