@@ -10,7 +10,7 @@ import numpy as np
 from ..__about__ import __version__ as version
 from .._common import _pick_first_int_data
 from .._files import open_file
-from .._helpers import register
+from .._helpers import register_format
 from .._mesh import Mesh
 
 meshio_only = {
@@ -468,4 +468,4 @@ def _write_table(f, data, ncol: int = 20):
             f.write(" {}\n".format(" ".join([str(l) for l in line])))
 
 
-register("flac3d", [".f3grid"], read, {"flac3d": write})
+register_format("flac3d", [".f3grid"], read, {"flac3d": write})
