@@ -8,7 +8,7 @@ import numpy as np
 from ..__about__ import __version__
 from .._exceptions import ReadError
 from .._files import open_file
-from .._helpers import register
+from .._helpers import register_format
 from .._mesh import CellBlock, Mesh
 
 permas_to_meshio_type = {
@@ -284,4 +284,6 @@ def write(filename, mesh):
         f.write("$FIN\n")
 
 
-register("permas", [".post", ".post.gz", ".dato", ".dato.gz"], read, {"permas": write})
+register_format(
+    "permas", [".post", ".post.gz", ".dato", ".dato.gz"], read, {"permas": write}
+)
